<?php

namespace Crm\Seller\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Seller\Events\SellerAction as SellerActionEvent;
use Crm\Seller\Notifications\SellerAction as SellerActionNotification;
use Litepie\Actions\Concerns\AsAction;

class SellerAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the SellerActionEvent.
     *
     * @param   SellerActionEvent  $event
     * @return mixed
     */
    public function handle(SellerActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $seller.
     *
     * @param   SellerActionEvent  $event
     * @return void
     */
    public function create(SellerActionEvent $event)
    {
        $client = $event->seller->client;
        Notification::send($client, new SellerActionNotification($event));
    }

    /**
     * Handle the SellerActionEvent as a listener.
     *
     * @param   SellerActionEvent  $event
     * @return mixed
     */
    public function asListener(SellerActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   SellerActionEvent  $event
     * @return bool
     */
    private function isAllowed(SellerActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
