<?php

namespace Crm\Seller\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Seller\Events\SellerWorkflow as SellerWorkflowEvent;
use Crm\Seller\Notifications\SellerWorkflow as SellerWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class SellerWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(SellerWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $seller is submitted.
     *
     * @param SellerWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(SellerWorkflowEvent $event)
    {
        $client = $event->seller->client;
        Notification::send($client, new SellerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $seller is published.
     *
     * @param SellerWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(SellerWorkflowEvent $event)
    {
        $client = $event->seller->client;
        Notification::send($client, new SellerWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $seller is approved.
     *
     * @param SellerWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(SellerWorkflowEvent $event)
    {
        $client = $event->seller->client;
        Notification::send($client, new SellerWorkflowNotification($event));
    }

    /**
     * Handles the $seller workflow event as a listener.
     *
     * @param SellerWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(SellerWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
