<?php

namespace Crm\Seller\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Seller\Models\Seller;

class SellerPolicy
{


    /**
     * Determine if the given user can view the seller.
     *
     * @param Authenticatable $user
     * @param Seller $seller
     *
     * @return bool
     */
    public function view(Authenticatable $user, Seller $seller)
    {
        if ($authUser->canDo('seller.seller.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $seller->is_owner;
    }

    /**
     * Determine if the given user can create a seller.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('seller.seller.create');
    }

    /**
     * Determine if the given user can update the given seller.
     *
     * @param Authenticatable $user
     * @param Seller $seller
     *
     * @return bool
     */
    public function update(Authenticatable $user, Seller $seller)
    {
        if ($user->canDo('seller.seller.edit') && $user->isAdmin()) {
            return true;
        }

        return $seller->is_owner;
    }

    /**
     * Determine if the given user can delete the given seller.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Seller $seller)
    {
        return $seller->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
